import squint.*;
import javax.swing.*;

/*
 * SimplePopClient --- This program allows its user to view
 * mail messages accessed through a POP client
 */
public class SimplePopClient extends GUIManager {
    // Change these values to adjust the size of the program's window
    private final int WINDOW_WIDTH = 650, WINDOW_HEIGHT = 550;
    
    // Size of all of the text fields used in the program
    private final int FIELD_WIDTH = 15;
    
    // Dimensions for text areas used to display messages and server responses
    private final int TEXTAREA_WIDTH = 50;
    private final int LOG_HEIGHT = 5;
    private final int MESSAGE_HEIGHT = 20;
   
    // Used to enter the POP account identifier
    JTextField user;
        
    // Used to enter the POP account password
    JPasswordField pass;
        
    // Used to enter the number of the message to retrieve
    JTextField messageNum;
        
    // Email messages are displayed in this area
    JTextArea message;
        
    // +OK and -ERR messages from the server are displayed in this area
    JTextArea log;
    
    // The current connection to the server
    NetConnection toServer;
        
    /*
     * Install all of the required GUI components
     */
    public SimplePopClient() {
        this.createWindow( WINDOW_WIDTH, WINDOW_HEIGHT );
        
        // Each JLabel/JTextArea pair is placed together in a pane of their own
        JPanel curPanel;
        
        // Create fields for entering the account information
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Mail Account:" ) );
        user = new JTextField( FIELD_WIDTH );
        curPanel.add( user );
        contentPane.add( curPanel );
        
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Password:" ) );
        pass = new JPasswordField( FIELD_WIDTH );
        curPanel.add( pass );
        contentPane.add( curPanel );
        
        // Create a field for the message number
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Message Number To Retrieve:" ) );
        messageNum = new JTextField( FIELD_WIDTH );
        curPanel.add( messageNum );
        contentPane.add( curPanel );
        
        // Install the button and text areas in the window
        contentPane.add( new JButton( "Get Message" ) );
        message = new JTextArea( MESSAGE_HEIGHT, TEXTAREA_WIDTH );
        contentPane.add( new JScrollPane( message ) );
        JTextArea log;
        log = new JTextArea( LOG_HEIGHT, TEXTAREA_WIDTH );
        contentPane.add( new JScrollPane( log ) );

    }
    
    /*
     * When the button is clicked, interact with the POP server to
     * access the requested message.
     */
    public void buttonClicked( JButton which ) {
        // Connect to the server and display initial response
        toServer = new NetConnection( "cortland.williams.edu", 110 );       
        log.setText( toServer.in.nextLine() + "\n" );
        
        // Send account information and display responses
        toServer.out.println( "USER " + user.getText() );
        log.append( toServer.in.nextLine() + "\n" );
        toServer.out.println( "PASS " + new String( pass.getPassword()) );
        log.append( toServer.in.nextLine() + "\n" );
        
        // Retrieve and display the specified email message
        toServer.out.println( "RETR " + messageNum.getText() );
        log.append( toServer.in.nextLine() + "\n" );
        toServer.addMessageListener( this );
        
        // Terminate the connection
        toServer.out.println( "QUIT" );
    }
   
    public void dataAvailable( ) {
        String serverResponse = toServer.in.nextLine();
        if ( serverResponse.startsWith( "+OK" ) ) {
            log.append( serverResponse + "\n" );
            toServer.close();
        } else {
            message.append( serverResponse + "\n" );
        }
    }
      
    public void connectionClosed( ) {
        log.append( "Server has closed connection\n" );
        toServer.close();
    }
}